@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Provide musical cadence chords
 
-our $VERSION = '0.0402';
+our $VERSION = '0.0403';
 
 use Moo;
 use Music::Chord::Note;
@@ -136,7 +136,7 @@ Music::Cadence - Provide musical cadence chords
 
 =head1 VERSION
 
-version 0.0402
+version 0.0403
 
 =head1 SYNOPSIS
 
@@ -195,7 +195,13 @@ append."
 
 =head2 new
 
-  $mc = Music::Cadence->new;
+  $mc = Music::Cadence->new;  # Use defaults
+
+  $mc = Music::Cadence->new(  # Override defaults
+    key    => $key,
+    scale  => $scale,
+    octave => $octave,
+  );
 
 Create a new C<Music::Cadence> object.
 
